Finite Volume parallel diffusion
================================

This is a simple example showing how to use the finite volume [parallel
diffusion][diffusion] operator.

[diffusion]: https://bout-dev.readthedocs.io/en/latest/user_docs/differential_operators.html#parallel-diffusion
